#!/usr/bin/make -f
# Typeset Markdown documentation files for GPU Hackathon Jülich into PDF
# Individual PDFs for each .md will be created plus one concatenated, large PDF of all .md files.
#
# Andreas Herten, March 2017, March 2019

MAKEFILE = $(CURDIR)/$(word $(words $(MAKEFILE_LIST)),$(MAKEFILE_LIST))

LC = pandoc

LCFLAGS = --pdf-engine=xelatex --variable mainfont="PT Serif"
LCFLAGS += --highlight-style pygments 
LCFLAGS += --number-sections
LCFLAGS += --variable lang:en
LCFLAGS += --variable colorlinks
LCFLAGS += --variable geometry:margin=1in
LCFLAGS += --variable author:"Andreas Herten <a.herten@fz-juelich.de>"

# SRC = $(wildcard *.md)
SRC = README.md

PDFS = $(SRC:.md=.pdf)

# all: $(PDFS) docu.pdf
all: docu.pdf

%.pdf: %.md $(MAKEFILE)
	sed "s/→/$$\\\rightarrow$$/" $< | $(LC) $(LCFLAGS) -o pdf/$@

docu.pdf: LCFLAGS += --toc 
docu.pdf: LCFLAGS += --variable title:"Helmholtz GPU Hackathon 2023 User Guide"
docu.pdf: LCFLAGS += --variable abstract:"Some hints for participants and mentors of the GPU Hackathon 2023 at Jülich Supercomputing Centre. \textit{Hack Away!}"
docu.pdf: LCFLAGS += --variable institute:"Forschungszentrum Jülich"
docu.pdf: LCFLAGS += --variable keywords:"GPU,CUDA,OpenACC,FZJ,JSC"
docu.pdf: $(SRC) $(MAKEFILE)
	$(LC) $(LCFLAGS) -o pdf/$@ $(SRC)

.PHONY: clean
clean:
	rm pdf/*.pdf
